macro_rules! counter {
($($tt:tt)*) => { ... };
}Expand description
Records an increment to the named monotonic counter (as a u64) with the given attributes.
spin_telemetry::metrics::counter!(spin.metric_name = 1, metric_attribute = "value");macro_rules! counter {
($($tt:tt)*) => { ... };
}Records an increment to the named monotonic counter (as a u64) with the given attributes.
spin_telemetry::metrics::counter!(spin.metric_name = 1, metric_attribute = "value");